@@ -1,13 +1,14 @@
+import pytest
 
 def server_from_config(config):
     from couchdbkit import Server
-    backend = config.getini('couchdbkit_backend')
+    backend = config.getini('couchdbkit_backend') or 'thread'
     return Server(backend=backend)
 
 def dbname_from_config(config, fmt):
     suffix = config.getini('couchdbkit_suffix')
     if not suffix:
-        pytest.fail('no couchdbkit_suffix set in ini')
+        pytest.xfail('no couchdbkit_suffix set in ini')
     return fmt % (suffix,)
 
 
